==> IEDB_NG_TC2-0.1-beta.tar.gz: ng_tc2-0.1-beta/method/netmhciipan-4.2-executable/setup.py <==
import os
from setuptools import setup, find_packages

# allow setup.py to be run from any path
os.chdir(os.path.normpath(os.path.join(os.path.abspath(__file__), os.pardir)))


# Get all of the Linux_x86_64/ data/ test/ files for use as package data
def recursive_walk(startdir):
    file_list = []
    for dirname, subdirList, fileList in os.walk(startdir, followlinks=True):
        if '.svn' in subdirList:
            subdirList.remove('.svn')
        for fname in fileList:
            file_list.append(os.path.join(dirname, fname))
            for sdname in subdirList:
                sdfiles = recursive_walk(sdname)
                file_list.extend(sdfiles)
    return file_list

pkg_data_files = ['netMHCIIpan', 'netMHCIIpan.1', 'NetMHCIIpan-4.2.pl', 'netMHCIIpan-4.2.readme']
os.chdir('netmhciipan_4_2_executable')

for subdir in ['data', 'Linux_x86_64', 'test']:
    file_list = recursive_walk(subdir)
    pkg_data_files.extend(file_list)
os.chdir(os.pardir)

with open(os.path.join(os.path.dirname(__file__), 'README.rst')) as readme:
    README = readme.read()

setup(
    name='netmhciipan-4.2-executable',
    version='4.2.0.0',
    author='Jason Yan',
    author_email='jyan@lji.org',
    packages=['netmhciipan_4_2_executable'],
    package_data={ 'netmhciipan_4_2_executable': pkg_data_files },
    description='Python package to provide netMHCIIpan-4.2 executable',
    long_description=README,
    install_requires=['allele-info>=3.8.0', 'iedbtools-utilities>=0.11.1'],
    keywords='T cell epitope prediction',
    classifiers=[
        'Intended Audience :: Developers',
        'Operating System :: POSIX :: Linux',
        'Programming Language :: Python :: 3',
    ]
)

==> IEDB_NG_TC2-0.1.1-beta.tar.gz: ng_tc2-0.1.1-beta/method/netmhciipan-4.3-executable/setup.py <==
import os
from setuptools import setup, find_packages

# allow setup.py to be run from any path
os.chdir(os.path.normpath(os.path.join(os.path.abspath(__file__), os.pardir)))


# Get all of the Linux_x86_64/ data/ test/ files for use as package data
def recursive_walk(startdir):
    file_list = []
    for dirname, subdirList, fileList in os.walk(startdir, followlinks=True):
        if '.svn' in subdirList:
            subdirList.remove('.svn')
        for fname in fileList:
            file_list.append(os.path.join(dirname, fname))
            for sdname in subdirList:
                sdfiles = recursive_walk(sdname)
                file_list.extend(sdfiles)
    return file_list

pkg_data_files = ['netMHCIIpan', 'netMHCIIpan.1', 'netMHCIIpan-4.3.readme']
os.chdir('netmhciipan_4_3_executable')

for subdir in ['data', 'Linux_x86_64', 'test']:
    file_list = recursive_walk(subdir)
    pkg_data_files.extend(file_list)
os.chdir(os.pardir)

with open(os.path.join(os.path.dirname(__file__), 'README.rst')) as readme:
    README = readme.read()

setup(
    name='netmhciipan-4.3-executable',
    version='4.3.0.0',
    author='Jason Yan',
    author_email='jyan@lji.org',
    packages=['netmhciipan_4_3_executable'],
    package_data={ 'netmhciipan_4_3_executable': pkg_data_files },
    description='Python package to provide netMHCIIpan-4.3 executable',
    long_description=README,
    install_requires=['allele-info>=3.8.0', 'iedbtools-utilities>=0.11.1'],
    keywords='T cell epitope prediction',
    classifiers=[
        'Intended Audience :: Developers',
        'Operating System :: POSIX :: Linux',
        'Programming Language :: Python :: 3',
    ]
)
